@@ -1,11 +1,5 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2021-2024 Nitrokey Developers
-#
-# Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-# http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-# http://opensource.org/licenses/MIT>, at your option. This file may not be
-# copied, modified, or distributed except according to those terms.
+# Copyright Nitrokey GmbH
+# SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import logging
 import os.path
@@ -544,6 +538,8 @@ def validate_update(ctx: Context[Bootloader, Device], image: str) -> None:
         raise CliException("Failed to validate firmware image", e, support_hint=False)
 
     print(f"version:      {container.version}")
+    if container.sdk:
+        print(f"Nitrokey SDK: >= {container.sdk}")
     if container.pynitrokey:
         print(f"pynitrokey:   >= {container.pynitrokey}")
 
